Page 26 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 26

Home

    beautiful garden with luxurious resting places. Here amid
    sparkling streams, fruit trees, and flowers he was
    attended by beautiful women serving him wine in gold
    and silver vessels as soft music played in the

    background.

    After enjoying all the delights of what he believed
    was paradise, he was again drugged and, while once
    more unconscious, carried back to the presence of the
    Grand Master. Upon awakening, he was assured that he
    had never left the side of the Grand Master but had

    merely experienced a foretaste of the paradise that
    awaited him if he obeyed the orders of his masters.

    In this matter the Assassins established a system of
    organized murder on a basis of religious fervor, and
    unleashed a reign of terror throughout the East. Years
    later, in secret records released by two of their own
    leaders, a list was found of celebrated men of all nations
    who had been their victims.

    Eventually, the leaders of the Assassins turned on
    each other and became the victims of the poisons and
    daggers they had prepared for others. Although the
    dynasty of the Assassins had ended by 1250, the sects
    from which they derived continued.

    The Knights Templar is another example of the end
    results of secret societies. After the First Crusade had

    ended with the defeat of the Muslims and the capture of
    Jerusalem, a band of nine Frenchmen formed an order (in
    1118) for the protection of pilgrims to the Holy
    Sepulchre. The King of Jerusalem presented them with

    21

    Secret Societies